@@ -21,7 +21,7 @@ else
 
 if ($step > count ($stepfunc))
 {
-	$root = (empty($_SERVER['HTTPS']) or $_SERVER['HTTPS'] == 'off') ? 'http://' : 'https://';
+	$root = (empty ($_SERVER['HTTPS']) || $_SERVER['HTTPS'] == 'off') ? 'http://' : 'https://';
 	$root .= isset ($_SERVER['HTTP_HOST']) ? $_SERVER['HTTP_HOST'] : ($_SERVER['SERVER_NAME'].($_SERVER['SERVER_PORT']=='80'?'':$_SERVER['SERVER_PORT']));
 	// "Since PHP 4.3.0, you will often get a slash or a dot back from
 	// dirname() in situations where the older functionality would have given
@@ -89,7 +89,7 @@ echo "<input type=hidden name=step value='${next_step}'>\n";
 function not_already_installed()
 {
 	global $found_secret_file, $pdo_dsn;
-	if ($found_secret_file and isset ($pdo_dsn))
+	if ($found_secret_file && isset ($pdo_dsn))
 	{
 		echo 'Your configuration file exists and seems to hold necessary data already.<br>';
 		return FALSE;
@@ -146,7 +146,7 @@ function init_config ()
 	if (!is_writable ($path_to_secret_php))
 	{
 		echo "The $path_to_secret_php file is not writable by web-server. Make sure it is.";
-		echo "The following commands should suffice:<pre>touch '$path_to_secret_php'; chmod 666 '$path_to_secret_php'</pre>";
+		echo "The following commands should suffice:<pre>touch '$path_to_secret_php'; chmod a=rw '$path_to_secret_php'</pre>";
 		echo 'Fedora Linux with SELinux may require this file to be owned by specific user (apache) and/or executing "setenforce 0" for the time of installation. ';
 		echo 'SELinux may be turned back on with "setenforce 1" command.<br>';
 		return FALSE;
@@ -156,7 +156,7 @@ function init_config ()
 		print_form();
 		return FALSE;
 	}
-	if (empty ($_REQUEST['mysql_db']) or empty ($_REQUEST['mysql_username']))
+	if (empty ($_REQUEST['mysql_db']) || empty ($_REQUEST['mysql_username']))
 	{
 		print_form
 		(
@@ -171,7 +171,7 @@ function init_config ()
 		echo '<h2 class=trerror>Missing database/username parameter!</h2>';
 		return FALSE;
 	}
-	if ($_REQUEST['conn'] == 'conn_tcp' and empty ($_REQUEST['mysql_host']))
+	if ($_REQUEST['conn'] == 'conn_tcp' && empty ($_REQUEST['mysql_host']))
 	{
 		print_form
 		(
@@ -186,7 +186,7 @@ function init_config ()
 		echo '<h2 class=trerror>Missing TCP hostname parameter!</h2>';
 		return FALSE;
 	}
-	if ($_REQUEST['conn'] == 'conn_unix' and empty ($_REQUEST['mysql_socket']))
+	if ($_REQUEST['conn'] == 'conn_unix' && empty ($_REQUEST['mysql_socket']))
 	{
 		print_form
 		(
@@ -207,7 +207,7 @@ function init_config ()
 	{
 	case 'conn_tcp':
 		$pdo_dsn .= 'host=' . $_REQUEST['mysql_host'];
-		if (!empty ($_REQUEST['mysql_port']) and $_REQUEST['mysql_port'] != '3306')
+		if (! empty ($_REQUEST['mysql_port']) && $_REQUEST['mysql_port'] != '3306')
 			$pdo_dsn .= ';port=' . $_REQUEST['mysql_port'];
 		break;
 	case 'conn_unix':
@@ -312,7 +312,7 @@ ENDOFTEXT
 function get_process_owner()
 {
 	// this function requires the posix extention and returns the fallback value otherwise
-	if (is_callable('posix_getpwuid') and is_callable('posix_geteuid'))
+	if (is_callable ('posix_getpwuid') && is_callable ('posix_geteuid'))
 	{
 		$user = posix_getpwuid(posix_geteuid());
 		if (isset ($user['name']))
@@ -324,7 +324,7 @@ function get_process_owner()
 function check_config_access()
 {
 	global $path_to_secret_php;
-	if (! is_writable ($path_to_secret_php) and is_readable ($path_to_secret_php))
+	if (! is_writable ($path_to_secret_php) && is_readable ($path_to_secret_php))
 	{
 		echo 'The configuration file ownership/permissions seem to be OK.<br>';
 		return TRUE;
@@ -341,7 +341,7 @@ function check_config_access()
 	echo 'For example, if httpd runs as user "' . $uname . '" and group "nogroup", commands ';
 	echo 'similar to the following may work (though not guaranteed to, please consider ';
 	echo 'only as an example):';
-	echo "<pre>chown $uname:nogroup secret.php; chmod 400 secret.php</pre>";
+	echo "<pre>chown $uname:nogroup secret.php; chmod 440 secret.php</pre>";
 	return FALSE;
 }
 
@@ -386,9 +386,6 @@ function init_database_static ()
 		echo "<tr><td>${part}</td>";
 		$nq = $nerrs = 0;
 		foreach (get_pseudo_file ($part) as $q)
-		{
-			if (empty ($q))
-				continue;
 			try
 			{
 				$result = $dbxlink->query ($q);
@@ -400,7 +397,6 @@ function init_database_static ()
 				$errorInfo = $dbxlink->errorInfo();
 				$failures[] = array ($q, $errorInfo[2]);
 			}
-		}
 		echo "<td>${nq}</td><td>${nerrs}</td></tr>\n";
 	}
 	if (!count ($failures))
@@ -445,7 +441,7 @@ function init_database_dynamic ()
 {
 	connect_to_db_or_die();
 	global $dbxlink;
-	if (!isset ($_REQUEST['password']) or empty ($_REQUEST['password']))
+	if (! isset ($_REQUEST['password']) || empty ($_REQUEST['password']))
 	{
 		$result = $dbxlink->query ('select count(user_id) from UserAccount where user_id = 1');
 		$row = $result->fetch (PDO::FETCH_NUM);
@@ -798,7 +794,7 @@ function get_pseudo_file ($name)
   `presented_username` char(64) NOT NULL,
   `successful_hash` char(40) NOT NULL,
   `first_success` timestamp NOT NULL default CURRENT_TIMESTAMP,
-  `last_retry` timestamp NOT NULL default '0000-00-00 00:00:00',
+  `last_retry` timestamp NULL default NULL,
   `displayed_name` char(128) default NULL,
   `memberof` text,
   UNIQUE KEY `presented_username` (`presented_username`),
@@ -1114,7 +1110,7 @@ function get_pseudo_file ($name)
   `user` char(64) NOT NULL,
   UNIQUE KEY `user_varname` (`user`,`varname`),
   KEY `varname` (`varname`),
-  CONSTRAINT `UserConfig-FK-varname` FOREIGN KEY (`varname`) REFERENCES `Config` (`varname`) ON DELETE CASCADE
+  CONSTRAINT `UserConfig-FK-varname` FOREIGN KEY (`varname`) REFERENCES `Config` (`varname`) ON DELETE CASCADE ON UPDATE CASCADE
 ) ENGINE=InnoDB";
 
 		$query[] = "CREATE TABLE `VLANDescription` (
@@ -1376,6 +1372,16 @@ ENDOFTRIGGER;
 		$query[] = "CREATE TRIGGER `Link-before-insert` BEFORE INSERT ON `Link` FOR EACH ROW $link_trigger_body";
 		$query[] = "CREATE TRIGGER `Link-before-update` BEFORE UPDATE ON `Link` FOR EACH ROW $link_trigger_body";
 
+		$port_trigger_body = <<<ENDOFTRIGGER
+PortTrigger:BEGIN
+  IF (NEW.`l2address` IS NOT NULL AND (SELECT COUNT(*) FROM `Port` WHERE `l2address` = NEW.`l2address` AND `object_id` != NEW.`object_id`) > 0) THEN
+    CALL `Port-l2address-already-exists-on-another-object`;
+  END IF;
+END;
+ENDOFTRIGGER;
+		$query[] = "CREATE TRIGGER `Port-before-insert` BEFORE INSERT ON `Port` FOR EACH ROW $port_trigger_body";
+		$query[] = "CREATE TRIGGER `Port-before-update` BEFORE UPDATE ON `Port` FOR EACH ROW $port_trigger_body";
+
 		$query[] = "CREATE VIEW `Location` AS SELECT O.id, O.name, O.has_problems, O.comment, P.id AS parent_id, P.name AS parent_name
 FROM `Object` O
 LEFT JOIN (
@@ -1428,8 +1434,8 @@ WHERE O.objtype_id = 1562";
 (6,'uint','number of ports'),
 (7,'float','max. current, Ampers'),
 (8,'float','power load, percents'),
-(14,'string','contact person'),
 (13,'float','max power, Watts'),
+(14,'string','contact person'),
 (16,'uint','flash memory, MB'),
 (17,'uint','DRAM, MB'),
 (18,'uint','CPU, MHz'),
@@ -1700,7 +1706,8 @@ WHERE O.objtype_id = 1562";
 (11,'CFP'),
 (12,'CFP2'),
 (13,'CPAK'),
-(14,'CXP')";
+(14,'CXP'),
+(15,'QSFP28')";
 
 		$query[] = "INSERT INTO `PortOuterInterface` VALUES
 (16,'AC-in'),
@@ -1735,6 +1742,10 @@ WHERE O.objtype_id = 1562";
 (1082,'empty XFP'),
 (1084,'empty SFP+'),
 (1087,'1000Base-T (Dell 1855)'),
+(1088,'1000Base-BX40-D'),
+(1089,'1000Base-BX40-U'),
+(1090,'1000Base-BX80-D'),
+(1091,'1000Base-BX80-U'),
 (1195,'100Base-FX'),
 (1196,'100Base-SX'),
 (1197,'100Base-LX10'),
@@ -1888,7 +1899,7 @@ WHERE O.objtype_id = 1562";
 (1465,'10GBase-ER-DWDM40-29.55 (ITU 60)'),
 (1466,'10GBase-ER-DWDM40-28.77 (ITU 61)'),
 (1469,'virtual port'),
-(1588,'empty QSFP+'),
+(1588,'empty QSFP'),
 (1589,'empty CFP2'),
 (1590,'empty CPAK'),
 (1591,'empty CXP'),
@@ -1928,6 +1939,8 @@ WHERE O.objtype_id = 1562";
 (1,1196),(2,1196),(3,1196),(4,1196),              -- 100Base-SX: 2xMMF
 (13,19),(14,19),(15,19),(16,19),(17,19),          -- 100Base-TX: Cat.5+ TP
 (11,1206),(12,1206),(11,1207),(12,1207),          -- 1000Base-BX10: 1xSMF
+(11,1088),(12,1088),(11,1089),(12,1089),          -- 1000Base-BX40: 1xSMF
+(11,1090),(12,1090),(11,1091),(12,1091),          -- 1000Base-BX80: 1xSMF
 (5,1204),(6,1204),                                -- 1000Base-LX: 2xSMF
 (5,1205),(6,1205),                                -- 1000Base-LX10: 2xSMF
 (1,1202),(2,1202),(3,1202),(4,1202),              -- 1000Base-SX: 2xMMF
@@ -1968,23 +1981,42 @@ WHERE O.objtype_id = 1562";
 (1505,1507),
 (1506,4),
 (1506,1504),
+(1787,4),
 (1787,8),
 (1787,1502)";
 
 		$query[] = "INSERT INTO `PortInterfaceCompat` VALUES
+-- SFP-100: empty SFP-100, 100Base-FX, 100Base-SX, 100Base-LX10, 100Base-BX10-D, 100Base-BX10-U, 100Base-EX, 100Base-ZX
 (2,1208),(2,1195),(2,1196),(2,1197),(2,1198),(2,1199),(2,1200),(2,1201),
+-- GBIC: empty GBIC, 1000Base-T, 1000Base-ZX, 1000Base-EX, 1000Base-SX, 1000Base-SX+, 1000Base-LX, 1000Base-LX10, 1000Base-BX10-D, 1000Base-BX10-U
 (3,1078),(3,24),(3,34),(3,42),(3,1202),(3,1203),(3,1204),(3,1205),(3,1206),(3,1207),
+-- SFP-1000: empty SFP-1000, 1000Base-T, 1000Base-ZX, 1000Base-EX, 1000Base-SX, 1000Base-SX+, 1000Base-LX, 1000Base-LX10, 1000Base-BX10-D, 1000Base-BX10-U
 (4,1077),(4,24),(4,34),(4,42),(4,1202),(4,1203),(4,1204),(4,1205),(4,1206),(4,1207),
+-- SFP-1000: 1000Base-BX40-D, 1000Base-BX40-U, 1000Base-BX80-D, 1000Base-BX80-U
+(4,1088),(4,1089),(4,1090),(4,1091),
+-- XENPAK: empty XENPAK, 10GBase-SR, 10GBase-ER, 10GBase-LR, 10GBase-LRM, 10GBase-ZR, 10GBase-LX4, 10GBase-CX4
 (5,1079),(5,30),(5,35),(5,36),(5,37),(5,38),(5,39),(5,40),
+-- X2: empty X2, 10GBase-SR, 10GBase-ER, 10GBase-LR, 10GBase-LRM, 10GBase-ZR, 10GBase-LX4, 10GBase-CX4
 (6,1080),(6,30),(6,35),(6,36),(6,37),(6,38),(6,39),(6,40),
+-- XPAK: empty XPAK, 10GBase-SR, 10GBase-ER, 10GBase-LR, 10GBase-LRM, 10GBase-ZR, 10GBase-LX4, 10GBase-CX4
 (7,1081),(7,30),(7,35),(7,36),(7,37),(7,38),(7,39),(7,40),
+-- XFP: empty XFP, 10GBase-SR, 10GBase-ER, 10GBase-LR, 10GBase-LRM, 10GBase-ZR, 10GBase-LX4, 10GBase-CX4
 (8,1082),(8,30),(8,35),(8,36),(8,37),(8,38),(8,39),(8,40),
+-- SFP+: empty SFP+, 10GBase-SR, 10GBase-ER, 10GBase-LR, 10GBase-LRM, 10GBase-ZR, 10GBase-LX4, 10GBase-CX4
 (9,1084),(9,30),(9,35),(9,36),(9,37),(9,38),(9,39),(9,40),
+-- QSFP+: empty QSFP, 40GBase-FR, 40GBase-ER4, 40GBase-SR4, 40GBase-LR4
 (10,1588),(10,1660),(10,1662),(10,1663),(10,1664),
+-- CFP: empty CFP, 100GBase-SR10, 100GBase-LR4, 100GBase-ER4, 100GBase-SR4, 100GBase-KR4, 100GBase-KP4, 100GBase-LR10, 100GBase-ER10
 (11,1668),(11,1669),(11,1670),(11,1671),(11,1672),(11,1673),(11,1674),(11,1675),(11,1676),
+-- CFP2: empty CFP2, 100GBase-SR10, 100GBase-LR4, 100GBase-ER4, 100GBase-SR4, 100GBase-KR4, 100GBase-KP4, 100GBase-LR10, 100GBase-ER10
 (12,1589),(12,1669),(12,1670),(12,1671),(12,1672),(12,1673),(12,1674),(12,1675),(12,1676),
+-- CPAK: empty CPAK, 100GBase-SR10, 100GBase-LR4, 100GBase-ER4, 100GBase-SR4, 100GBase-KR4, 100GBase-KP4, 100GBase-LR10, 100GBase-ER10
 (13,1590),(13,1669),(13,1670),(13,1671),(13,1672),(13,1673),(13,1674),(13,1675),(13,1676),
+-- CXP: empty CXP, 100GBase-CR4, 100GBase-CR10
 (14,1591),(14,1677),(14,1678),
+-- QSFP28: empty QSFP, 40GBase-FR, 40GBase-ER4, 40GBase-SR4, 40GBase-LR4, 100GBase-LR4, 100GBase-ER4, 100GBase-SR4, 100GBase-KR4, 100GBase-KP4
+(15,1588),(15,1660),(15,1662),(15,1663),(15,1664),(15,1670),(15,1671),(15,1672),(15,1673),(15,1674),
+-- hardwired: AC-in, 100Base-TX, 1000Base-T, RS-232 (RJ-45), virtual bridge, KVM (host), KVM (console), RS-232 (DB-9), RS-232 (DB-25), AC-out, DC, virtual port
 (1,16),(1,19),(1,24),(1,29),(1,31),(1,33),(1,446),(1,681),(1,682),(1,1322),(1,1399),(1,1469)";
 
 		$query[] = "INSERT INTO `PortCompat` (`type1`, `type2`) VALUES
@@ -2018,6 +2050,8 @@ WHERE O.objtype_id = 1562";
 (1077,1077),
 (1084,1084),
 (1087,1087),
+(1088,1089),
+(1090,1091),
 (1195,1195),
 (1196,1196),
 (1197,1197),
@@ -2246,7 +2280,7 @@ WHERE O.objtype_id = 1562";
 ('TAGS_QUICKLIST_THRESHOLD','50','uint','yes','no','yes','Tags quick list threshold'),
 ('ENABLE_MULTIPORT_FORM','no','string','no','no','yes','Enable \"Add/update multiple ports\" form'),
 ('DEFAULT_PORT_IIF_ID','1','uint','no','no','no','Default port inner interface ID'),
-('DEFAULT_PORT_OIF_IDS','1=24; 3=1078; 4=1077; 5=1079; 6=1080; 8=1082; 9=1084; 10=1588; 11=1668; 12=1589; 13=1590; 14=1591','string','no','no','no','Default port outer interface IDs'),
+('DEFAULT_PORT_OIF_IDS','1=24; 3=1078; 4=1077; 5=1079; 6=1080; 8=1082; 9=1084; 10=1588; 11=1668; 12=1589; 13=1590; 14=1591; 15=1588','string','no','no','no','Default port outer interface IDs'),
 ('IPV4_TREE_RTR_AS_CELL','no','string','no','no','yes','Show full router info for each network in IPv4 tree view'),
 ('PROXIMITY_RANGE','0','uint','yes','no','yes','Proximity range (0 is current rack only)'),
 ('VLANSWITCH_LISTSRC', '', 'string', 'yes', 'no', 'yes', 'List of VLAN running switches'),
@@ -2269,7 +2303,7 @@ WHERE O.objtype_id = 1562";
 ('PORT_EXCLUSION_LISTSRC','{\$typeid_3} or {\$typeid_10} or {\$typeid_11} or {\$typeid_1505} or {\$typeid_1506}','string','yes','no','no','List source: objects without ports'),
 ('FILTER_RACKLIST_BY_TAGS','yes','string','yes','no','yes','Rackspace: show only racks matching the current object\'s tags'),
 ('MGMT_PROTOS','ssh: {\$typeid_4}; telnet: {\$typeid_8}','string','yes','no','yes','Mapping of management protocol to devices'),
-('SYNC_802Q_LISTSRC','','string','yes','no','no','List of VLAN switches sync is enabled on'),
+('SYNC_8021Q_LISTSRC','','string','yes','no','no','List of VLAN switches sync is enabled on'),
 ('QUICK_LINK_PAGES','depot,ipv4space,rackspace','string','yes','no','yes','List of pages to display in quick links'),
 ('CACTI_LISTSRC','false','string','yes','no','no','List of object with Cacti graphs'),
 ('CACTI_RRA_ID','1','uint','no','no','yes','RRA ID for Cacti graphs displayed in RackTables'),
