@@ -10,7 +10,7 @@ function renderConfigMainpage ()
 	global $pageno, $page;
 	echo '<ul>';
 	foreach ($page as $cpageno => $cpage)
-		if (isset ($cpage['parent']) and $cpage['parent'] == $pageno  && permitted($cpageno))
+		if (isset ($cpage['parent']) && $cpage['parent'] == $pageno && permitted ($cpageno))
 			echo '<li>' . mkA (getTitle ($cpageno), $cpageno) . "</li>\n";
 	echo '</ul>';
 }
@@ -257,17 +257,15 @@ function renderOIFCompatEditor()
 	global $nextorder, $wdm_packs;
 
 	startPortlet ('WDM wideband receivers');
-	echo '<table border=0 align=center cellspacing=0 cellpadding=5>';
+	echo '<table border=0 align=center cellspacing=0 cellpadding=5 class=zebra>';
 	echo '<tr><th>&nbsp;</th><th>enable</th><th>disable</th></tr>';
-	$order = 'odd';
 	foreach ($wdm_packs as $codename => $packinfo)
 	{
-		echo "<tr class=row_${order}><td class=tdleft>" . $packinfo['title'] . '</td><td>';
+		echo '<tr><td class=tdleft>' . $packinfo['title'] . '</td><td>';
 		echo getOpLink (array ('op' => 'addPack', 'standard' => $codename), '', 'add');
 		echo '</td><td>';
 		echo getOpLink (array ('op' => 'delPack', 'standard' => $codename), '', 'delete');
 		echo '</td></tr>';
-		$order = $nextorder[$order];
 	}
 	echo '</table>';
 	finishPortlet();
@@ -278,6 +276,7 @@ function renderOIFCompatEditor()
 	echo '<tr><th>&nbsp;</th><th>From Interface</th><th>To Interface</th></tr>';
 	if (getConfigVar ('ADDNEW_AT_TOP') == 'yes')
 		printNewitemTR();
+	$order = 'odd';
 	foreach (getPortOIFCompat() as $pair)
 	{
 		if ($last_left_oif_id != $pair['type1'])
@@ -368,20 +367,17 @@ function renderIIFOIFCompatEditor()
 
 function renderPortOIFViewer()
 {
-	global $nextorder;
-	echo '<br><table class=cooltable align=center border=0 cellpadding=5 cellspacing=0>';
+	echo '<br><table class="cooltable zebra" align=center border=0 cellpadding=5 cellspacing=0>';
 	echo '<tr><th>Origin</th><th>Key</th><th>Refcnt</th><th>Outer Interface</th></tr>';
-	$order = 'odd';
 	$refcnt = getPortOIFRefc();
 	foreach (getPortOIFOptions() as $oif_id => $oif_name)
 	{
-		echo "<tr class=row_${order}>";
+		echo '<tr>';
 		echo '<td class=tdleft>' . getImageHREF ($oif_id < 2000 ? 'computer' : 'favorite') . '</td>';
 		echo "<td class=tdright>${oif_id}</td>";
 		echo '<td class=tdright>' . ($refcnt[$oif_id] ? $refcnt[$oif_id] : '&nbsp;') . '</td>';
 		echo '<td class=tdleft>' . stringForTD ($oif_name, 48) . '</td>';
 		echo '</tr>';
-		$order = $nextorder[$order];
 	}
 	echo '</table>';
 }
@@ -447,14 +443,13 @@ function renderPortOIFEditor()
 
 function renderAttributes ()
 {
-	global $nextorder, $attrtypes;
+	global $attrtypes;
 	startPortlet ('Optional attributes');
-	echo "<table class=cooltable border=0 cellpadding=5 cellspacing=0 align=center>";
+	echo '<table class="cooltable zebra" border=0 cellpadding=5 cellspacing=0 align=center>';
 	echo "<tr><th class=tdleft>Attribute name</th><th class=tdleft>Attribute type</th><th class=tdleft>Applies to</th></tr>";
-	$order = 'odd';
 	foreach (getAttrMap() as $attr)
 	{
-		echo "<tr class=row_${order}>";
+		echo '<tr>';
 		echo "<td class=tdleft>${attr['name']}</td>";
 		echo "<td class=tdleft>" . $attrtypes[$attr['type']] . "</td>";
 		echo '<td class=tdleft>';
@@ -467,7 +462,6 @@ function renderAttributes ()
 				else
 					echo decodeObjectType ($app['objtype_id']) . '<br>';
 		echo '</td></tr>';
-		$order = $nextorder[$order];
 	}
 	echo "</table><br>\n";
 	finishPortlet();
@@ -669,15 +663,21 @@ function renderChapter ($tgt_chapter_no)
 	{
 		echo "<tr class=row_${order}><td>";
 		printImageHREF ($key < 50000 ? 'computer' : 'favorite');
-		echo "</td><td class=tdright>${key}</td><td>";
+		echo "</td><td class=tdright>${key}</td><td class=tdright>";
 		if ($refcnt[$key])
 		{
-			$cfe = '';
-			foreach ($attrs as $attr_id)
+			// For the ObjectType chapter the extra filter is as simple as "{\$typeid_${key}}" but
+			// the reference counter also includes the relations with AttributeMap.objtype_id hence
+			// it often is not the same as the amount of objects that match the expression. With
+			// this in mind don't display the counter as a link for this specific chapter.
+			if ($tgt_chapter_no == CHAP_OBJTYPE)
+				$cfe = '';
+			else
 			{
-				if (! empty($cfe))
-					$cfe .= ' or ';
-				$cfe .= '{$attr_' . $attr_id . '_' . $key . '}';
+				$tmp = array();
+				foreach ($attrs as $attr_id)
+					$tmp[] = "{\$attr_${attr_id}_${key}}";
+				$cfe = implode (' or ', $tmp);
 			}
 
 			if (! empty($cfe))
@@ -749,7 +749,7 @@ function renderChapterEditor ($tgt_chapter_no)
 	}
 	if (getConfigVar ('ADDNEW_AT_TOP') != 'yes')
 		printNewItemTR();
-	echo "</table>\n";
+	echo "</table>\n<br>";
 }
 
 // $v is a $configCache item
@@ -762,21 +762,18 @@ function renderConfigVarName ($v)
 
 function renderUIConfig ()
 {
-	global $nextorder;
 	startPortlet ('Current configuration');
-	echo '<table class=cooltable border=0 cellpadding=5 cellspacing=0 align=center width="70%">';
+	echo '<table class="cooltable zebra" border=0 cellpadding=5 cellspacing=0 align=center width="70%">';
 	echo '<tr><th class=tdleft>Option</th><th class=tdleft>Value</th></tr>';
-	$order = 'odd';
 	foreach (loadConfigCache() as $v)
 	{
 		if ($v['is_hidden'] != 'no')
 			continue;
-		echo "<tr class=row_${order}>";
+		echo '<tr>';
 		echo "<td nowrap valign=top class=tdright>";
 		renderConfigVarName ($v);
 		echo '</td>';
 		echo "<td valign=top class=tdleft>${v['varvalue']}</td></tr>";
-		$order = $nextorder[$order];
 	}
 	echo "</table>\n";
 	finishPortlet();
@@ -828,12 +825,11 @@ function renderUIResetForm()
 	echo "</form>";
 }
 
-function renderTagRowForViewer ($taginfo, $level = 0)
+function serializeTagStats ($taginfo)
 {
-	$self = __FUNCTION__;
 	$statsdecoder = array
 	(
-		'total' => ' total records linked',
+		'total' => ' total record(s) linked',
 		'object' => ' object(s)',
 		'rack' => ' rack(s)',
 		'file' => ' file(s)',
@@ -843,7 +839,21 @@ function renderTagRowForViewer ($taginfo, $level = 0)
 		'ipv4vs' => ' IPv4 virtual service(s)',
 		'ipv4rspool' => ' IPv4 real server pool(s)',
 		'vst' => ' VLAN switch template(s)',
+		'ipvs' => ' VS group(s)',
 	);
+	$stats = array ("tag ID = ${taginfo['id']}");
+	if ($taginfo['kidc'])
+		$stats[] = "${taginfo['kidc']} sub-tag(s)";
+	if ($taginfo['refcnt']['total'])
+		foreach ($taginfo['refcnt'] as $article => $count)
+			if (array_key_exists ($article, $statsdecoder))
+				$stats[] = $count . $statsdecoder[$article];
+	return implode (', ', $stats);
+}
+
+function renderTagRowForViewer ($taginfo, $level = 0)
+{
+	$self = __FUNCTION__;
 	$trclass = '';
 	if ($level == 0)
 		$trclass .= ' separator';
@@ -854,12 +864,7 @@ function renderTagRowForViewer ($taginfo, $level = 0)
 	echo "<tr class='${trclass}'><td align=left style='padding-left: " . ($level * 16) . "px;'>";
 	if (count ($taginfo['kids']))
 		printImageHREF ('node-expanded-static');
-	$stats = array ("tag ID = ${taginfo['id']}");
-	if ($taginfo['refcnt']['total'])
-		foreach ($taginfo['refcnt'] as $article => $count)
-			if (array_key_exists ($article, $statsdecoder))
-				$stats[] = $count . $statsdecoder[$article];
-	echo '<span title="' . implode (', ', $stats) . '" class="' . getTagClassName ($taginfo['id']) . '">' . $taginfo['tag'];
+	echo '<span title="' . serializeTagStats ($taginfo) . '" class="' . getTagClassName ($taginfo['id']) . '">' . $taginfo['tag'];
 	echo ($refc ? " <i>(${refc})</i>" : '') . '</span></td></tr>';
 	foreach ($taginfo['kids'] as $kid)
 		$self ($kid, $level + 1);
@@ -882,8 +887,8 @@ function renderTagRowForEditor ($taginfo, $parent_name = NULL, $level = 0)
 	echo "<tr${trclass}><td align=left style='padding-left: " . ($level * 16) . "px;'>";
 	if ($taginfo['kidc'])
 		printImageHREF ('node-expanded-static');
-	if ($taginfo['refcnt']['total'] > 0 or $taginfo['kidc'])
-		printImageHREF ('nodestroy', $taginfo['refcnt']['total'] . ' references, ' . $taginfo['kidc'] . ' sub-tags');
+	if ($taginfo['refcnt']['total'] > 0 || $taginfo['kidc'])
+		printImageHREF ('nodestroy', serializeTagStats ($taginfo));
 	else
 		echo getOpLink (array ('op' => 'destroyTag', 'tag_id' => $taginfo['id']), '', 'destroy', 'Delete tag');
 	echo '</td><td>';
@@ -1049,21 +1054,15 @@ function renderMyQuickLinks ()
 
 function renderCactiConfig()
 {
+	$columns = array
+	(
+		array ('th_text' => 'base URL', 'row_key' => 'base_url'),
+		array ('th_text' => 'username', 'row_key' => 'username'),
+		array ('th_text' => 'graph(s)', 'row_key' => 'num_graphs', 'td_class' => 'tdright'),
+	);
 	$servers = getCactiServers();
 	startPortlet ('Cacti servers (' . count ($servers) . ')');
-	echo '<table cellspacing=0 cellpadding=5 align=center class=widetable>';
-	echo '<tr>' .
-		'<th>base URL</th>' .
-		'<th>username</th>' .
-		'<th>graph(s)</th>' .
-		'</tr>';
-	foreach ($servers as $server)
-		echo '<tr align=left valign=top>' .
-			'<td>' . stringForTD ($server['base_url']) . '</td>' .
-			'<td>' . stringForTD ($server['username']) . '</td>' .
-			"<td class=tdright>${server['num_graphs']}</td>" .
-			'</tr>';
-	echo '</table>';
+	renderTableViewer ($columns, $servers);
 	finishPortlet();
 }
 
@@ -1115,16 +1114,14 @@ function renderCactiServersEditor()
 
 function renderMuninConfig()
 {
+	$columns = array
+	(
+		array ('th_text' => 'base URL', 'row_key' => 'base_url', 'td_maxlen' => 150),
+		array ('th_text' => 'graph(s)', 'row_key' => 'num_graphs', 'td_class' => 'tdright'),
+	);
 	$servers = getMuninServers();
 	startPortlet ('Munin servers (' . count ($servers) . ')');
-	echo '<table cellspacing=0 cellpadding=5 align=center class=widetable>';
-	echo '<tr><th>base URL</th><th>graph(s)</th></tr>';
-	foreach ($servers as $server)
-	{
-		echo '<tr align=left valign=top><td>' . stringForTD ($server['base_url']) . '</td>';
-		echo "<td class=tdright>${server['num_graphs']}</td></tr>";
-	}
-	echo '</table>';
+	renderTableViewer ($columns, $servers);
 	finishPortlet();
 }
 
