@@ -279,6 +279,18 @@ $image['html']['height'] = 16;
 $image['pencil']['path'] = 'pix/pencil-icon.png';
 $image['pencil']['width'] = 12;
 $image['pencil']['height'] = 12;
+$image['link up']['path'] = 'pix/link-up.png';
+$image['link up']['width'] = 16;
+$image['link up']['height'] = 16;
+$image['link down']['path'] = 'pix/link-down.png';
+$image['link down']['width'] = 16;
+$image['link down']['height'] = 16;
+$image['link disabled']['path'] = 'pix/link-disabled.png';
+$image['link disabled']['width'] = 16;
+$image['link disabled']['height'] = 16;
+$image['16x16t']['path'] = 'pix/1x1t.gif';
+$image['16x16t']['width'] = 16;
+$image['16x16t']['height'] = 16;
 
 $page_by_realm = array();
 $page_by_realm['object'] = 'depot';
@@ -334,7 +346,7 @@ function getSelect ($optionList, $select_attrs = array(), $selected_id = NULL, $
 	return $ret;
 }
 
-function printNiftySelect ($groupList, $select_attrs = array(), $selected_id = NULL, $autocomplete = false)
+function printNiftySelect ($groupList, $select_attrs = array(), $selected_id = NULL)
 {
 	echo getNiftySelect ($groupList, $select_attrs, $selected_id);
 }
@@ -345,7 +357,7 @@ function printNiftySelect ($groupList, $select_attrs = array(), $selected_id = N
 function getNiftySelect ($groupList, $select_attrs, $selected_id = NULL)
 {
 	// special treatment for ungrouped data
-	if (count ($groupList) == 1 and isset ($groupList['other']))
+	if (count ($groupList) == 1 && isset ($groupList['other']))
 		return getSelect ($groupList['other'], $select_attrs, $selected_id);
 	if (!array_key_exists ('name', $select_attrs))
 		return '';
@@ -402,26 +414,33 @@ function printImageHREF ($tag, $title = '', $do_input = FALSE)
 function getImageHREF ($tag, $title = '', $do_input = FALSE)
 {
 	global $image;
-	if (!isset ($image[$tag]))
-		$tag = 'error';
-	$img = $image[$tag];
-	$img['path'] = '?module=chrome&uri=' . $img['path'];
-	if ($do_input == TRUE)
-		return
-			"<input type=image name=submit class=icon " .
-			"src='${img['path']}' " .
-			"border=0 " .
-			(!strlen ($title) ? '' : " title='${title}'") . // JT: Add title to input hrefs too
-			">";
+	$attrs = array
+	(
+		'src' => array_key_exists ($tag, $image) ?
+			'?module=chrome&uri=' . $image[$tag]['path'] :
+			'?module=image&img=error',
+		'border' => 0,
+	);
+	if ($title != '')
+		$attrs['title'] = $title;
+	if ($do_input)
+	{
+		$element = 'input';
+		$attrs['type'] = 'image';
+		$attrs['name'] = 'submit';
+		$attrs['class'] = 'icon';
+		// Width and height for INPUT only appear in HTML 5.
+	}
 	else
-		return
-			"<img " .
-			"src='${img['path']}' " .
-			"width=${img['width']} " .
-			"height=${img['height']} " .
-			"border=0 " .
-			(!strlen ($title) ? '' : "title='${title}'") .
-			">";
+	{
+		$element = 'img';
+		if (array_key_exists ($tag, $image))
+		{
+			$attrs['width'] = $image[$tag]['width'];
+			$attrs['height'] = $image[$tag]['height'];
+		}
+	}
+	return makeHtmlTag ($element, $attrs);
 }
 
 function escapeString ($value, $do_db_escape = FALSE)
@@ -440,7 +459,7 @@ function transformRequestData()
 	global $sic;
 	// Magic quotes feature is deprecated, but just in case the local system
 	// still has it activated, reverse its effect.
-	$do_magic_quotes = (function_exists ('get_magic_quotes_gpc') and get_magic_quotes_gpc());
+	$do_magic_quotes = function_exists ('get_magic_quotes_gpc') && get_magic_quotes_gpc();
 	$seen_keys = array();
 
 	// Escape any globals before we ever try to use them, but keep a copy of originals.
@@ -488,7 +507,7 @@ function addJS ($data, $inline = FALSE, $group = 'default')
 		return $javascript;
 	}
 	// Add jquery.js and racktables.js the first time a Javascript file is added.
-	if (empty($javascript))
+	if (! count ($javascript))
 	{
 		$javascript = array
 		(
@@ -559,7 +578,7 @@ function getRenderedIPv4NetCapacity ($range)
 		$total = ip4_range_size ($range);
 
 		// compute $a_total: own range size, without subranges
-		if (! isset ($range['kidc']) or $range['kidc'] == 0)
+		if (! isset ($range['kidc']) || $range['kidc'] == 0)
 			$a_total = $total;
 		else
 		{
@@ -609,7 +628,7 @@ function getRenderedIPv4NetCapacity ($range)
 		addJS ('js/net-usage.js');
 
 		$free_text = '';
-		if (isset ($range['kidc']) and $range['kidc'] > 0)
+		if (isset ($range['kidc']) && $range['kidc'] > 0)
 		{
 			$free_masks = array_keys ($range['spare_ranges']);
 			sort ($free_masks, SORT_NUMERIC);
@@ -743,7 +762,7 @@ function serializeTags ($chain, $baseurl = '')
 	foreach ($chain as $taginfo)
 	{
 		$title = '';
-		if (isset ($taginfo['user']) and isset ($taginfo['time']))
+		if (isset ($taginfo['user']) && isset ($taginfo['time']))
 			$title = htmlspecialchars ($taginfo['user'] . ', ' . formatAge ($taginfo['time']), ENT_QUOTES);
 		if (isset($taginfo['parent_id']))
 		{
@@ -751,11 +770,11 @@ function serializeTags ($chain, $baseurl = '')
 			foreach ($taglist[$taginfo['id']]['trace'] as $tag_id)
 				$parent_info[] = $taglist[$tag_id]['tag'];
 			$parent_info[] = $taginfo['tag'];
-			if (strlen ($title))
+			if ($title != '')
 				$title .= "\n";
 			$title .= implode (" &rarr;  ", $parent_info);
 		}
-		if (strlen ($title))
+		if ($title != '')
 			$title = "title='$title'";
 
 		$class = '';
@@ -796,17 +815,17 @@ function getPageName ($page_code)
 
 function printTagTRs ($cell, $baseurl = '')
 {
-	if (getConfigVar ('SHOW_EXPLICIT_TAGS') == 'yes' and count ($cell['etags']))
+	if (getConfigVar ('SHOW_EXPLICIT_TAGS') == 'yes' && count ($cell['etags']))
 	{
 		echo "<tr><th width='50%' class=tagchain>Explicit tags:</th><td class=tagchain>";
 		echo serializeTags ($cell['etags'], $baseurl) . "</td></tr>\n";
 	}
-	if (getConfigVar ('SHOW_IMPLICIT_TAGS') == 'yes' and count ($cell['itags']))
+	if (getConfigVar ('SHOW_IMPLICIT_TAGS') == 'yes' && count ($cell['itags']))
 	{
 		echo "<tr><th width='50%' class=tagchain>Implicit tags:</th><td class=tagchain>";
 		echo serializeTags ($cell['itags'], $baseurl) . "</td></tr>\n";
 	}
-	if (getConfigVar ('SHOW_AUTOMATIC_TAGS') == 'yes' and count ($cell['atags']))
+	if (getConfigVar ('SHOW_AUTOMATIC_TAGS') == 'yes' && count ($cell['atags']))
 	{
 		echo "<tr><th width='50%' class=tagchain>Automatic tags:</th><td class=tagchain>";
 		echo serializeTags ($cell['atags']) . "</td></tr>\n";
@@ -835,7 +854,7 @@ function renderEntitySummary ($cell, $title, $values = array())
 	echo "<table border=0 cellspacing=0 cellpadding=3 width='100%'>\n";
 	foreach ($values as $name => $value)
 	{
-		if (is_array ($value) and count ($value) == 1)
+		if (is_array ($value) && count ($value) == 1)
 		{
 			$value = array_shift ($value);
 			echo $value;
@@ -881,16 +900,16 @@ function getOpLink ($params, $title,  $img_name = '', $comment = '', $class = ''
 		$ret = '<a href="#" onclick="return false;"';
 		$class .= ' noclick';
 	}
-	if (! empty ($comment))
+	if ($comment != '')
 		$ret .= ' title="' . htmlspecialchars ($comment, ENT_QUOTES) . '"';
 	$class = trim ($class);
-	if (! empty ($class))
+	if ($class != '')
 		$ret .= ' class="' . htmlspecialchars ($class, ENT_QUOTES) . '"';
 	$ret .= '>';
-	if (! empty ($img_name))
+	if ($img_name != '')
 	{
 		$ret .= getImageHREF ($img_name, $comment);
-		if (! empty ($title))
+		if ($title != '')
 			$ret .= ' ';
 	}
 	if (FALSE !== strpos ($class, 'need-confirmation'))
@@ -905,17 +924,17 @@ function getPopupLink ($helper, $params, $window_name = '', $img_name = '', $tit
 	$popup_args = 'height=700, width=700, location=no, menubar=no, resizable=yes, scrollbars=yes, status=no, titlebar=no, toolbar=no';
 	$ret .= '<a href="#"';
 	$class = trim ($class);
-	if (! empty ($class))
+	if ($class != '')
 		$ret .= ' class="' . htmlspecialchars ($class, ENT_QUOTES) . '"';
-	if (! empty ($comment))
+	if ($comment != '')
 		$ret .= 'title="' . htmlspecialchars ($comment, ENT_QUOTES) . '"';
 	$href = makeHref (array ('module' => 'popup', 'helper' => $helper) + makePageParams ($params));
 	$ret .= " onclick=\"window.open('$href', '$window_name', '$popup_args'); return false\">";
 
-	if (! empty ($img_name))
+	if ($img_name != '')
 	{
 		$ret .= getImageHREF ($img_name, $comment);
-		if (! empty ($title))
+		if ($title != '')
 			$ret .= ' ';
 	}
 	$ret .= $title;
@@ -1028,11 +1047,11 @@ function makeFileDownloadButton ($file_id, $imgname = 'download')
 function niftyString ($string, $maxlen = 30, $usetags = TRUE)
 {
 	$cutind = '&hellip;'; // length is 1
-	if (!mb_strlen ($string))
+	if ($string == '')
 		return '&nbsp;';
 	// a tab counts for a space
 	$string = preg_replace ("/\t/", ' ', $string);
-	if (!$maxlen or mb_strlen ($string) <= $maxlen)
+	if (! $maxlen || mb_strlen ($string) <= $maxlen)
 		return htmlspecialchars ($string, ENT_QUOTES, 'UTF-8');
 	return
 		($usetags ? ("<span title='" . htmlspecialchars ($string, ENT_QUOTES, 'UTF-8') . "'>") : '') .
@@ -1077,7 +1096,7 @@ function stringForTextarea ($string)
 }
 
 // <OPTION>%s</OPTION>
-function stringForOption ($string, $maxlen = 30)
+function stringForOption ($string, $maxlen = 80)
 {
 	$string = preg_replace ("/\t/", ' ', $string);
 	if ($maxlen == 0 || mb_strlen ($string) <= $maxlen)
@@ -1142,7 +1161,7 @@ function enableTagsPicker ()
 
 function makeIPAllocLink ($ip_bin, $alloc, $display_ifname = FALSE)
 {
-	$object_name = ! isset ($object_name) || ! strlen ($object_name) ?
+	$object_name = ! isset ($object_name) || $object_name == '' ?
 		formatEntityName (spotEntity ('object', $alloc['object_id'])) :
 		$alloc['object_name'];
 	$title = $display_ifname ?
